@@ -97,7 +97,7 @@ class BaseHandler(tornado.web.RequestHandler):
         return Dict()
 
     async def prepare(self):
-        self.current_user = await awaitable(self.current_user)
+        self.current_user = await awaitable(self.get_current_user())
 
     @cached_property
     def ip(self):
@@ -218,12 +218,13 @@ class BaseHandler(tornado.web.RequestHandler):
             projection = {k: 1 for k in projection}
         cursor = db[collection].find(query, projection)
 
-        self.logger.info(f'{db.name}.{collection} query: {query}')
         self.args.setdefault('order', - 1)
         self.args.setdefault('page', 1)
         self.args.setdefault('count', 20)
         if self.args.sort:
             cursor = cursor.sort(self.args.sort, self.args.order)
+
+        self.logger.info(f'{db.name}.{collection} query: {query}, sort: {self.args.sort}')
         cursor = cursor.skip((self.args.page - 1) * self.args.count).limit(self.args.count)
 
         if isinstance(db, Motor):
