@@ -51,8 +51,8 @@ class BaseHandler(BaseHandler):
         username = self.get_argument('username', None)
         if not username:
             return Dict({'err': 1, 'msg': '请输入用户名'})
-        if len(username) < 6:
-            return Dict({'err': 1, 'msg': '用户名至少6个字符'})
+        if len(username) < 5:
+            return Dict({'err': 1, 'msg': '用户名至少5个字符'})
         if len(username) > 20:
             return Dict({'err': 1, 'msg': '用户名至多20个字符'})
         if await awaitable(self.db.users.find_one({'username': username})):
@@ -250,7 +250,7 @@ class ResetHandler(BaseHandler):
 class ActiveHandler(BaseHandler):
 
     async def get(self, code):
-        email = await awaitable(self.rd.get(f'active_{code}'))
+        email = await awaitable(self.rd.get(f'{self.prefix}_active_{code}'))
         if email:
             await awaitable(self.db.users.update_one({'email': email}, {'$set': {'active': True}}))
         self.redirect('/admin')
@@ -264,29 +264,31 @@ class ActiveHandler(BaseHandler):
 class EmailHandler(BaseHandler):
 
     async def get(self, action):
-        email = self.get_argument('email', None)
-        if not email:
+        if not self.args.email:
             return self.finish({'err': 1, 'msg': '请输入邮箱'})
 
         if action == 'reset':
-            user = await self.get_user(email)
-            if user:
-                email = user.email
-                title = f'{self.request.host} 重设密码邮件'
-                code = await self.gen_code(email)
-                content = f'您本次操作的验证码为: {code}'
-            else:
+            user = await self.get_user(self.args.email)
+            if not user:
                 return self.finish({'err': 1, 'msg': '用户不存在'})
+            title = f'{self.request.host} 重设密码邮件'
+            code = await self.gen_code(self.args.email)
+            content = f'您本次操作的验证码为: {code}'
+        elif action == 'check':
+            title = f'{self.request.host} 验证邮件'
+            code = await self.gen_code(self.args.email)
+            content = f'您本次操作的验证码为: {code}'
         elif action == 'active':
             title = f'{self.request.host} 激活邮件'
             code = uuid.uuid4().hex
-            await awaitable(self.rd.setex(f'active_{code}', 600, email))
+            key = f'{self.prefix}_active_{code}'
+            await awaitable(self.rd.setex(key, 600, self.args.email))
             url = f'https://{self.request.host}/active/{code}'
             content = f'请点击链接或将其复制到地址栏打开: <br><a href="{url}">{url}</a>'
         else:
             return self.finish({'err': 1, 'msg': 'action is not defined'})
 
-        await self.app.email.send(email, title, content)
+        await self.app.email.send(self.args.email, title, content)
         self.finish({'err': 0})
 
     post = get
