@@ -28,6 +28,7 @@ from .log_utils import Logger
 from .log_utils import WatchedFileHandler
 from .rabbitmq import AioPika
 from .rabbitmq import Pika
+from .redismq import RedisMQ
 from .utils import AioQueue
 from .utils import awaitable
 from .utils import ceil
@@ -63,6 +64,6 @@ __all__ = [
     'Email', 'AioEmail', 'Queue', 'AioQueue',
     'Config', 'Logger', 'WatchedFileHandler',
     'Mongo', 'MongoClient', 'Redis', 'AioRedis', 'Motor', 'MotorClient',
-    'Mysql', 'AioMysql', 'Pika', 'AioPika',
+    'Mysql', 'AioMysql', 'Pika', 'AioPika', 'RedisMQ',
     'Request', 'Response', 'Chrome',
 ]
