@@ -4,9 +4,11 @@
 Author: zhangkai
 Last modified: 2019-11-12 16:04:04
 '''
+
 import functools
 import logging
 import time
+import copy
 
 
 def synchronize(func):
@@ -48,7 +50,8 @@ def retry(func, count=2, raise_error=False):
     def wrapper(*args, **kwargs):
         for i in range(count):
             try:
-                return func(*args, **kwargs)
+                _kwargs = copy.deepcopy(kwargs)
+                return func(*args, **_kwargs)
             except Exception as e:
                 logger.exception(f'running exception: {e}, retry: {i + 1}')
                 if raise_error and i == count - 1:
@@ -64,7 +67,8 @@ def aioretry(func, count=2, raise_error=False):
     async def wrapper(*args, **kwargs):
         for i in range(count):
             try:
-                return await func(*args, **kwargs)
+                _kwargs = copy.deepcopy(kwargs)
+                return await func(*args, **_kwargs)
             except Exception as e:
                 logger.exception(f'running exception: {e}, retry: {i + 1}')
                 if raise_error and i == count - 1:
